#
# spec file for package distrobox
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           distrobox
Version:        1.8.1
Release:        1.1
Summary:        Use any linux distribution inside your terminal
License:        GPL-3.0-only
URL:            https://github.com/89luca89/distrobox
Source:         https://github.com/89luca89/distrobox/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        distrobox.conf
Requires:       %{_bindir}/basename
Requires:       %{_bindir}/find
Requires:       %{_bindir}/grep
Requires:       %{_bindir}/sed
Requires:       (%{_bindir}/podman or %{_bindir}/docker)
# Idea would be: if bash completion is already there, let's have it. If
# not, let's "only" recommend it...
Requires:       (%{name}-bash-completion if bash-completion)
# For distrobox-exec to work properly, we need flatpak helper services (bsc#1220037)
Requires:       flatpak
BuildRequires:  ImageMagick
BuildRequires:  hicolor-icon-theme
BuildArch:      noarch

%description
Use any Linux distribution inside your terminal.
Distrobox uses podman or docker to create containers using the Linux distribution of your choice.
The created container will be tightly integrated with the host,
allowing sharing of the HOME directory of the user, external storage,
external USB devices and graphical apps (X11/Wayland), and audio.

%package bash-completion
Summary:        Bash completion for %{name}
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for distrobox.

%prep
%autosetup -p1 -n distrobox-%{version}

%build

%install
./install --prefix %{buildroot}/%{_prefix}

install -d -m0755 %{buildroot}%{_docdir}/%{name}
install -m 0644 docs/*.md %{buildroot}%{_docdir}/%{name}

%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_distconfdir}/distrobox
install -m 0644 %{SOURCE1} %{buildroot}%{_distconfdir}/distrobox/distrobox.conf
%else
mkdir -p %{buildroot}%{_sysconfdir}/distrobox
install -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/distrobox/distrobox.conf
%endif

%files
%license COPYING.md
%doc %{_docdir}/%{name}
%{_bindir}/%{name}
%{_bindir}/%{name}-*
%{_mandir}/man1/%{name}.1.gz
%{_mandir}/man1/%{name}-*.1.gz
%if 0%{?suse_version} > 1500
%dir %{_distconfdir}/distrobox
%{_distconfdir}/distrobox/distrobox.conf
%else
%config %{_sysconfdir}/distrobox
%config(noreplace) %{_sysconfdir}/distrobox/distrobox.conf
%endif
%dir %{_datadir}/icons/hicolor/
%dir %{_datadir}/icons/hicolor/*x*/
%dir %{_datadir}/icons/hicolor/*x*/apps/
%dir %{_datadir}/zsh/site-functions/
%{_datadir}/icons/hicolor/*/apps/terminal-distrobox-icon.png
%{_datadir}/icons/hicolor/scalable/apps/terminal-distrobox-icon.svg
%{_datadir}/zsh/site-functions/_%{name}*

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}*

%changelog
* Tue Jan 21 2025 Paolo Stivanin <info@paolostivanin.com>
- update to 1.8.1:
  * assemble: add clone in distrobox assemble by @PawsFunctions in #1618
  * completions: zsh reworked. fixed not completing container names. by @fredricocalamari in #1603
  * create: better check clone support
  * create: properly handle platform specification for alien architectures. Fix #1644
  * distrobox-enter: improve cmd composition speed by @TigerGorilla2 in #1649
  * docs: Cut 80%% of the source package size by optimizing/cleaning doc images by @eugenesan in #1586
  * docs: Fix misspelling in Useful tips section by @brandondong in #1645
  * docs: Update compatibility list
  * docs: Update compatibility.md for fedora toolbox images by @ImBearChild in #1637
  * docs: add deepin 23 docker image by @chenchongbiao in #1632
  * docs: fix nvidia container toolkit commands. Fix #1654
  * docs: update Podman inside Distrobox by @alexandrevicenzi in #1597
  * enter: Replace tac with awk to be more portable by @shtayerc in #1591
  * enter: Stop importing zsh FPATH into container by @jgroman in #1636
  * enter: fix additional flags composition, Fix #1594
  * export: potential improvement to pull-request #1102 by @AbduEhab in #1608
  * fix:repeat trigger update locale when locale exists by @heysion in #1614
  * init: Strip single quotes when parsing locale.conf by @catgirlconspiracy in #1605
  * init: add timeout to systemd bringup wait. Fix #1641
  * init: fix missing hooks in pacman, Fix #1595, Fix #1602, Fix #1610, Fix #1619
  * init: fix prompt not sourcing on some distros
  * init: fix runtime sync fallback by @xz-dev in #1622
  * init: improve nvidia integration, skip files when directory is already a ro-mountpoint, log with warnings
  * init: move pkg manager exclude lists to separate step, always run them.
  * init: provide default prompt for fish shell by @Boria138 in #1588
  * init: simplify nvidia 32bit dir detection
  * rm: fix redundant print with quotes. Fix #1634
* Wed Oct 16 2024 Martin Sirringhaus <martin.sirringhaus@suse.com>
- update to 1.8.0
  * Improvements
  + Improvements on Nvidia integration
  + Improvements on XDG_* env variables management
  + Remote distrobox assemble files! Keep them remote with distrobox assemble create --file https://foo.com/file.ini!
  + A lot of new container distros, from @ublue-os and @toolbx-images, New Fedora, Ubuntu, Alpine and @wolfi-dev wolfi-toolbox!
  * all: ensure env variables are set and have values
  * all: use registry.fedoraproject.org/fedora-toolbox:latest image by default, Fix #1402
  * assemble: add support for remote manifest files
  * assemble: ensure variables are reset correctly
  * assemble: fix name detection with hyphens, Fix #1507
  * assemble: fix possible empty lines, Fix #1514
  * assemble: improve handling of hooks, pass around b64 encoded string to avoid unwanted evaluations
  * compatibility: add missing url for ubuntu:23.04 by @sheevy in #1439
  * create: better explain init/pre-init hooks
  * create: ignore trailing slashes on custom homes, Fix #1575
  * docs: Add kali icon by @andyspectre in #1451
  * docs: Document support for alpine 3.20 containers by @Ferenc- in #1504
  * docs: Fix issue with user not having permissions to write containers.conf by @nhermosilla14 in #1456
  * docs: Seperate curl and wget commands by @axtloss in #1434
  * docs: Update microos -> aeon/kalpa in docs by @TheRsKing in #1427
  * docs: Update openSUSE and SLES compatibility guide by @alexandrevicenzi in #1489
  * docs: add BlackaArch Linux compatibility, Fix #1358
  * docs: add compatibility with ghcr.io/ublue-os/bluefin-cli, Fix #1453
  * docs: document an official way to detect when you're in a distrobox
  * docs: document pipewire/alsa packages for ubuntu initful containers. Fix #1374
  * docs: fix subuids spelling mistake by @yocoldle in #1431
  * docs: fix link for Crystal linux. Fix #1418
  * docs: fix linting
  * docs: fix obsolete Chainguard Wolfi notes
  * docs: point to new nixos wiki by @Mic92 in #1384
  * docs: remove rhel-toolbox image from compatibility, it's now behind paywall
  * docs: support for 3d acceleration in: run_libvirt_in_distrobox.md by @TheRsKing in #1426
  * docs: update compatibility, add ublue toolboxes, update Alpine and Fedora versions, Fix #1501
  * docs: update vscode integration docs
  * enter: Fix distrobox-enter and distrobox-rm to handle containers that have environment variables shorter than 5 symbols by @senioroman4uk in #1545
  * enter: Fix support for Active Directory usernames including backslashes pt. 2 by @phoppermann in #1458
  * enter: fix additional flags evaluation, Fix #1541
  * enter: fix docker timestamp incompatibility, Fix #1382, Fix #1424, Fix #1392
  * enter: fix regression in login for initful container, Fix #1428
  * enter: get rid of eval and pass arguments using set. This will avoid maniupulating args, and simplify our life. Fix #749, Fix #1461
  * enter: improve positional args handling, treat enter command accordingly, improve comments explaining the black magic
  * export: Actually fix XDG_DATA_DIRS and XDG_DATA_HOME handling by @TigerGorilla2 in #1582
  * export: Fix XDG_DATA_DIRS and XDG_DATA_HOME handling by @e-luks in #1496
  * export: ensure destpath exists, Fix #1405
  * export: fix CONTAINER_ID fallback
  * export: fix grep errors on list-apps
  * export: improve documentation of the spec. Fix #1444
  * export: simplify and cleanup code
  * export: support exporting app launchers by full-path.
  * extras: vscode- improve podman wrapper, add docker wrapper, fix reconnections
  * fix for 1440 by @dtg01100 in #1441
  * fix: init package in Gentoo Stage3 image by @xz-dev in #1455
  * fix:[#1525] handle container creation failure by @jardon in #1526
  * generate-entry: add 'Remove' action to entry, Fix #1433
  * generate-entry: add timeout to downloads, Fix #1459
  * generate-entry: fix generic icon download and setup
  * generate-entry: fix linting
  * generate-entry: use XDG_DATA_HOME by @Samueru-sama in #1468
  * host-exec: fix arm naming, Fix #1442
  * host-exec: fix host-spawn version
  * host-exec: update host-spawn version
  * init: fix arch locale-gen by @Boria138 in #1520
  * init: Exclude repos from bind-mounting by @lunacd in #1503
  * init: Fix SHELL using absolute path and disable duplicate profile inclusion by @eugenesan in #1397
  * init: Generate host locales in container (fixed issue #1399) by @Boria138 in #1404
  * init: add fallback values for host locale variables
  * init: add iputils
  * init: add iputils in setup_pacman by @intzaaa in #1576
  * init: apt-get upgrade, force keeping old configs when non interactive
  * init: arrange package manager to avoid conflicts when using more than one (eg: packaging containers)
  * init: auto-link /usr/bin/flatpak, to better support opening links on host's browser, if those are flatpaks
  * init: do not fail in "Setting up read-only mounts" if findmnt does not exist by @phoppermann in #1454
  * init: ensure we have DBUS variables set for host-spawn to work in login scripts, Fix #1383
  * init: fallback case where mounting /etc/localtime fails, Fix #1435
  * init: fix detection of 32bit nvidia libs on suse family
  * init: fix failing chpasswd on systemd-homed managed users, Fix #1423
  * init: fix locale generation for minimal images
  * init: fix locale generation on musl and older systems
  * init: fix missing allowerasing flag for dnf
  * init: fix nvidia integration mounting files from boost libs, Fix #1500
  * init: fix nvidia integration, improve search of nvidia files, Fix #1500
  * init: fix typo in fallback locale values
  * init: fix udev clash on rootful initful systems
  * init: fix void-linux failing due to runit, Fix #1380
  * init: perform upgrade before setting up archlinux packages
  * init: proper fix for void extraction paths. Fix #1457
  * init: remove su-exec workaround for Wolfi, now that it supports proper sudo
  * init: rework package managment code
  * init: separate 'mount --rbind -o rslave ...' into 'mount --rbind ...'… by @timwa0669 in #1583
  * rm: Fix distrobox-enter and distrobox-rm to handle containers that have environment variables shoter than 5 symbols by @senioroman4uk in #1545
  * rm: add fallback value to response_force
  * rm: ask to force-delete if running and in interactive mode
  * rm: fix IFS overwriting, Fix #1400
  * rm: remove dead code, remove container volumes.
* Sat May 11 2024 jun wang <jgwang@suse.com>
- Update to version 1.7.2.1
  + changes from 1.7.2.1
  * chore(init): Add sudo to Wolfi (#1375)
  * Add fedora toolbox 40 to list of compatible images (#1377)
  * init: fix setting empty DISPLAY variable, breaking gpg
  + changes from 1.7.2
  * all: properly handle env vars and configs in all commands
    (#1328)
  * chore: bump CI actions, minor fixes to README and other
    files (#1345)
  * docs: Specify that distrobox is in the extra repo (#1316)
  * docs: Support latest alpine (#1341)
  * docs: Update copyright in footer (#1365)
  * docs: Update useful_tips.md (#1330)
  * enter: make log_timestamp date format universally
    compatible (#1343)
  * export: cancel export when trying to delete (#1340)
  * export: consider only absolute candidate icon paths that
    exist (#1318)
  * init: Support musl variant of Void Linux (#1327)
  * init: add explicit creation of /etc/fish/conf.d (#1348)
  * init: massively speed up apt/pacman/xbps deps install (#1324)
  * install: use more portable install(1) arguments (#1364)
  * CI: fix hostname test
  * CI: try to ensure enough disk space
  * CI: use shell-funcheck
  * all: improve function docs
  * assemble: add custom hostname support
  * create: fix regression with rootless runc 1.20~rc1 (#1359)
  * docs: add Slackware 15 (#1357)
  * docs: move upgrading instruction a bit more ahead (#1342)
  * docs: update xhost command to be silent (#1350)
  * enter: Fix support for Active Directory usernames including
    backslashes (#1360)
  * enter: fix regression in fish shell login with initful
    systems
  * enter: fix typo in command generation (#1331)
  * export: fix duplicate extra_flags (#1311)
  * export: use different symbol for IFS (#1351)
  * init, create: use $CONTAINER_ID to distinguish container's
    prompts. Use host's hostname by default.
  * init: ensure fish config is sourced only on interactive
    shell (#1292)
  * init: fix endless hook append (#1320)
  * init: fix performance regression in skel file setup (#1317)
  * init: forward wayland display only if it is set
  * rm: revert 22bc081, simplify removal of exported
    app/bins (#1301)
* Mon Mar 25 2024 Michal Vyskocil <michal.vyskocil@gmail.com>
- Update to 1.7.1
  * all: ensure no side effects on global variables
  * create the binary export path if it doesn't exist (#1291)
  * docs: Add info on upgrading package on steamdeck (#1271)
  * docs: remove extra ` from xhost command by (#1284)
  * enter: Add option to run with clean PATH (#1299)
  * fix: missing .fifo logfile in distrobox-enter (#1307)
  * init: ignore findmnt error in routine remounting (#1289) (#1296)
  * init: mask suspend/hibernate/hybrid-sleep
  * init: massively speed up apk deps install by @JamiKettunen in (#1298)
  * rm: do not block container removal if we cannot start it
* Fri Mar 15 2024 Dario Faggioli <dfaggioli@suse.com>
- Update to current git version in order to include the code that
  fixes the problem of ImageMagick not being able to resize the
  icons dynamically. This means including the following commits:
  * install: fix linting
  * assemble: fix regression in file reading
  * chore: fix typo (#1283)
  * install: fix installation script (#1282)
  * install: add fixed resolution png icons for use on desktops (#1280)
  * Update install (#1278)
* Thu Mar 14 2024 Michal Vyskocil <michal.vyskocil@gmail.com>
- Update to 1.7.0.1
  * install: fix version
  * distrobox-generate-entry: respect DBX_CONTAINER_MANAGER variable
  * distrobox-init: do not fail if locale cannot be set by
  * Don't create empty XAUTH* variables.
  * Add DISTROBOX_EXPORT_PATH env var for distrobox-export.
  * distrobox-init: use "zypper se --match-exact" (instead of "zypper se -x")
  * init: better detection of file watching trigger
  * enter: fix shell when entering initful container after
  * export: fix quotes arount exported binary path
  * upgrade: fix execution with new enter behavior
  * enter: do not use a shell when executing a custom command
  * export: fix execution of binaries with spaces in the name
  * rm: do not fail if no exports are found
* Wed Feb 28 2024 Shawn Dunn <sfalken@opensuse.org>
- Removed:
  * 0001-Fix-systemd-init-container-startup-1069.patch
- Update to 1.7.0
  * added --enter-flags to distrobox-export to specify additional
    distrobox flags to use when entering
  * added --hostname flag to distrobox-create so you can choose a
    different hostname than the box name
  * added --unshare-groups to distrobox-create to allow unsharing
    user's additional groups inside the container
  * better login shell management
  * better systemd support for initful containers
  * fixed multiple bins and apps exports declaration in assemble
  * improved NVidia support
  * improved Wolfi container support
  * improved rootful containers support for exported graphical apps
  * improved terminfo support
  * new distrobox-export --list-apps and --list-binaries to show
    exported apps and binaries
* Thu Feb 22 2024 Dario Faggioli <dfaggioli@suse.com>
- Add flatpak as a dependency, as we need it for distrobox-host-exec
  to work properly (bsc#1220037)
* Wed Feb 21 2024 Enrico Belleri <kilgore.trout@idesmi.eu>
- Add 0001-Fix-systemd-init-container-startup-1069.patch:
  * run podman exec command as root since some distros would ask
    for user password when using su to login even though the user
    has no password in /etc/shadow
  * fix pam_systemd not being checked for su
* Tue Nov 21 2023 Michal Vyskocil <michal.vyskocil@gmail.com>
- Update to version 1.6.0.1:
  * Export: fix exporting desktop app.
  * Init: fix nvidia library integration.
- Update to version 1.6.0:
  * Lilipod support
  * Improved nvidia integration, particularly for cuda
  * General improvements in the init process
  * Improve user's shell handling, so that it now always respects the chsh done inside the container
  * Fix tzdata/zoneinfo problems
  * Rootful containers now will properly setup user password for sudo
  * General polish in initful containers
  * Initful containers now support also OpenRC when present
  * Initful containers will now have also a proper systemd user session
  * New --unshare-all, --unshare-netns, --unshare-process, --unshare-devsys
    flags in create
    + Now initful + unshare-all containers can be used as playgrounds for
    services like LXC and Libvirt more easily
  * New container_additional_volumes configuration
  * Export fixes and improvements in multi-icon and space-in-name handling
  * Exported binaries will be runnable between distroboxes
  * Exported binaries will always run in a login shell
  * Assemble is now more polished and supports all of create flags
  * Assemble can now export apps/binaries directly from the manifest
* Fri Jul  7 2023 Frederic Crozat <fcrozat@suse.com>
- Update to version 1.5.0.2:
  * Fix typo in instructions for setting podman-host path
  * Fix user initialization for ubuntu 23.04
  * Compatibility: add openEULER and Linux Mint containers
  * Fix docker minimum version to 19.03.15.
  * Better container detection in host-exec
  * fix host file sync when unsharing network
- Changes from version 1.5.0.1:
  * Fix bashism in assemble.
  * Revert to using distrobox-enter for upgrade.
  * Fix bug in init_readlink with relative paths in init.
  * Improve dry-run output to show a flag for each line in enter/create.
* Sun Jun 18 2023 Enrico Belleri <kilgore.trout@idesmi.eu>
- Update to version 1.5.0:
  * additional-packages flag in create, to directly add packages during init
  * NVidia GPU Support for containers: distrobox will attempt to share host's drivers with the container
  * New distrobox-assemble command lets you declare your distroboxes-as-code, in an easy config file
  * Now, removing a distrobox will un-export apps and binaries exported by it
  * Init is now more flexible in how it adds packages, allowing for greater compatibility
  * Init now supports systemd containers using --additional-packages systemd during creation
  * General reliability improvements, lots of bug fixes and QoL
* Tue Feb 21 2023 Richard Brown <rbrown@suse.com>
- Remove container_image from .conf, obsoleted by
  container_image_default
- use official distrobox:latest container instead of vanilla
  tumbleweed to speedup start times, still call it tumbleweed
  because it is
* Tue Jan 24 2023 Predrag Ivanović <predivan@mts.rs>
- Use tubleweed:latest as the default image
  instead of, hardcoded in 'distrobox-create', fedora:toolbox.
* Wed Dec 28 2022 Ayush Kumar <ayush06feb@gmail.com>
- Update to latest version (1.4.2.1). Some changes:
  * all: fix setting up default images and names
  * compatibility: add gentoo docker image
  * compatibility: change debian 8 image
  * completion: Remove shebangs from bash completions
  * completion: add compatibility list flag, add image name
    autocompletion
  * create/enter/export: Add home prefix
  * create: Fix using --home with space in path
  * create: use --entrypoint to override entrypoint defined by
    image
  * distrobox: remove trap from the wrapper
  * docs: Add resource limitation tips
  * docs: Fix example configuration file
  * docs: Update handler function to support bash scripts
  * enter/export: handle quotes in arguments in a better way
  * enter: exclude LANG environment variables
  * enter: remove detach-keys, work on #398
  * export/enter: inject container ID at enter-time, in order to be
    used in export
  * export: fix variable declaration
  * export: look at global user services while trying to export a
    service
  * export: use realpath on icons
  * init: Add init and pre-init hook defaults as supported config
    options
  * init: add missing findmnt in OpenSUSE
  * init: better systemd unit cleanup
  * init: copy skel files only if using custom home
  * init: fix overriding of SHELL at each start, override default
    SHELL only the first time
  * init: fix sudoers spam (missing " in check)
  * init: fix void-linux package incompatibility error
  * init: fix vte installation; add --noreplace to prevent repeated
    builds
  * init: integrate with kerberos host only if it is installed on
    the host.
  * init: skip external mounts when searching for sockets
  * init: specify package for gentoo
  * init: use container's path for SHELL instead of host's one
  * init: use findmnt instead of mountpoint, fixing compatibility
    with old distributions
  * install-podman: Fix cni_plugin_dirs
  * install: do not use scraping, use fixed version
  * main: Do not open manpager automatically
  Full list available at: https://github.com/89luca89/distrobox/releases/tag/1.4.2.1
* Thu Nov 17 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not recommend bash-completion subpackage: this triggers
  installation even if bash-completion is not there yet. All (well,
  most for now) packages are handled to install the completion IF
  bash-completion is present (which is the default on standard
  setups).
* Thu Sep 29 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest version (1.4.1)
- Patches removed:
  0001-distrobox-if-no-command-is-specified-default-to-ente.patch
- Add a bash-completion subpackage
- Changes in 1.4.1:
  * completion: add bash completion support!
  * create/enter: revert 52a34fb
  * create: add --no-entry
  * docs: update host and guest lists
  * docs: redundant "else" in readme
  * init: add mesa and vulkan drivers by default
  * init: don't query filesystems mounted by beesd
  * install-podman: update to 4.2.1
  * install-podman: install crun, it generally
    works better in rootless.
  * install-podman: fix default configuration
  * ephemeral: do cleanup even in case of errors
  * generate-entry: auto-discover curl or wget.
* Wed Sep 14 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest version (1.4.0)
- Patches removed:
  0001-enter-fix-automatic-container-creation-when-r-is-use.patch
  0002-distrobox-handle-situations-with-weird-manpages-setu.patch
  0002-opensuse-check-for-the-config-file-in-usr-etc-too.patch
  0003-distrobox-if-no-command-is-specified-default-to-ente.patch
  0004-opensuse-check-for-the-config-file-in-usr-etc-too.patch
- Patches added:
  0001-distrobox-if-no-command-is-specified-default-to-ente.patch
- Changes in 1.4.0:
  * New distrobox upgrade command, to update all the containers at once
  * New distrobox generate-entry command, to add your distrobox to the app list
    note that from 1.4.0 onwards this will be the default behaviour for all the
    new containers created
  * New distrobox ephemeral command, to quickly spawn, use and delete a container.
    All-in-one.
  * New install-podman script to install Podman in $HOME. Handy for @ValveSoftware
    SteamDeck users
  * Distrobox-host-exec now uses exclusively the host-spawn command from @1player
  * Better support for AD/LDap and Kerberos usernames
  * Better support for Nix/Guix hosts
  * Plenty of bug fixes and CI/Test improvements smile
* Thu Jul 28 2022 Dario Faggioli <dfaggioli@suse.com>
- Fix a (potential0 problem with man and manpages
  * Patch added:
    0002-distrobox-handle-situations-with-weird-manpages-setu.patch
- Default to distrobox-enter when only typing distrobox
  * Patch added:
    0003-distrobox-if-no-command-is-specified-default-to-ente.patch
- Reordered the patchqueue:
  * Patch removed:
    0002-opensuse-check-for-the-config-file-in-usr-etc-too.patch
  * Patch added:
    0004-opensuse-check-for-the-config-file-in-usr-etc-too.patch
* Wed Jul 27 2022 Dario Faggioli <dfaggioli@suse.com>
- enable non-interactive mode by default
- Fix a but with automatic cretion of rootful containers
  * Patch added:
    0001-enter-fix-automatic-container-creation-when-r-is-use.patch
- Rework the /usr/etc config file patch (better changelog)
  * Patch removed:
    0001-Read-config-in-usr-etc-too.patch
  * Patch added:
    0002-opensuse-check-for-the-config-file-in-usr-etc-too.patch
- Switched to %%autosetup in the spec file
* Tue Jun 21 2022 Dario Faggioli <dfaggioli@suse.com>
- Move config file in vendor specific path by default
  * Patch added:
    0001-Read-config-in-usr-etc-too.patch
- Update to latest version, 1.3.1
  * all: allow users to specify non_interactive=true/false
  * all: improve code readability and formatting, follow happy paths
  * create: make it clearer to the user the container creation output
  * create: remove check about clone and image name
  * docs: Fix typo by @rugk in #308
  * docs: remove WSL2 entry, cannot actively check if works correctly
  * enter: automatically create containers during 'distrobox-enter' (if they don't exist!)
  * export: add --root to rooful containers
  * export: fix DBusActivatable not working
  * host-exec docs: 755 -> 644
  * host-exec: change [N/y] to [y/N]
  * init: fix apt hooks to make systemd install work
  * init: move zypper recommends after the basic packages install,
    make OpenSUSE containers creation faster
  * install: add --next flag to install latest commit from git
  * stop: update misleading comment
  * uninstall: interactive rm won't work when executed throught pipe
  * docs: update compatibility list
  * Confirm support for:
    Redhat UBI 9
    Redhat UBI 9-init
    Redhat UBI 9-minimal
    AlmaLinux 8-minimal
    AlmaLinux 9-minimal
    AlmaLinux 9
* Mon May 30 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest version, 1.3.0:
  * new tools and commands!
  * rootful containers support
  * new supported distros
  * improved integration with the host
  * many fixes and improvements
  For full log, see: https://github.com/89luca89/distrobox/releases/tag/1.3.0
* Sat May 14 2022 Dario Faggioli <dfaggioli@suse.com>
- Add a config file, so that we pull a tumbleweed image by default
- Update to latest version, 1.2.15. Some changes:
  * init: Allow all package manager checks to run
  * init: Fix compatibility with init containers
  * init: add pacman post-hook to neutralize systemd post-hooks in case we're not in an init-enabled container
  * init: exclude dbus system socket sharing, it doesn't work and creates confusing error messages
  * init: fix missing check before umounting on init-enabled containers
  * init: fix new archlinux mount: /usr/lib/libmount.so.1: version MOUNT_2_38 not found (required by mount) error, upgrade before installing packages
  * init: fix regression introduced in 3f014de where containers where thinking they were on a booted systemd
  * init: improve arch linux integration - add pacman pre-post hooks to reduce number of errors occurring
  * create/enter: print error messages only when not in dry-run
  * create: add work around for incompatibility between systemd/journald ACLs and overlayfs
  * enter: check for container errors during first start
  * enter: do not instantiate a tty if we do not have one
  * enter: extract container SHELL from inspect, use that as fallback if no custom command provided
  * enter: fix boolean logic on tty use
  * enter: fix unbound variable with --dry-run
  * export: hide unuseful stderr in export
* Tue Mar 29 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest version 1.2.14. Some changes:
  * all: detect if running sudo and improve error messages for container managers, pointing to documentation
  * fix: move selinux fix into create phase
  * enter: escape --workdir argument
  * enter: Enter at workdir through child path of '/run/host' by @ennec-e in #186
  * stop: Add distrobox-stop command
  * enter: use container's $PATH when entering
  * create: resolve path before mounting
  * init: If user already exists in /etc/passwd set props again, do not skip
  * init: Fix grep match of very short user or group names
  * init: tighter systemd integration with host
  * init: support LDAP/AD mail usernames
  * export: support exporting of system flatpaks and document it
  Full list available at: https://github.com/89luca89/distrobox/releases/tag/1.2.14
- Switch from `install -p` to `install --prefix` (see
  https://github.com/89luca89/distrobox/pull/190)
* Fri Mar 11 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest version 1.2.13
- Fix some rpmlint suggested spec file issues
* Mon Jan 31 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest version (1.2.12)
- Add licence to the spec file and fix formatting, add some globbing
- Include the manpages in the package
- Add changelog file
  * File added: distrobox.changes
* Wed Jan 12 2022 Nathan D <dhanas.nathan@gmail.com>
- Initial package
